@@ -166,6 +166,28 @@ makeFilter(
   }
 )
 
+makeFilter(
+  name = "cforest.importance",
+  desc = "Permutation importance of random forest fitted in package 'party'",
+  pkg = "party",
+  supported.tasks = c("classif", "regr", "surv"),
+  supported.features = c("numerics", "factors"),
+  fun = function(task, nselect, ...) {
+    args = list(...)
+    cforest_args = as.list(base::args(party::cforest))
+    cforest_args = args[names(args) %in% names(cforest_args)]
+    control_args = as.list(base::args(party::cforest_control))
+    control_args = args[names(args) %in% names(control_args)]
+    varimp_args = as.list(base::args(party::varimp))
+    varimp_args = args[names(args) %in% names(varimp_args)]
+    ctrl = do.call(party::cforest_unbiased, control_args)
+    fit = do.call(party::cforest, c(list(formula = getTaskFormula(task), data = getTaskData(task), controls = ctrl),
+                                    cforest_args))
+    im = do.call(party::varimp, c(list(obj = fit), varimp_args))
+    im
+  }
+)
+
 makeFilter(
   name = "linear.correlation",
   desc = "Pearson correlation between feature and target",
@@ -282,7 +304,7 @@ makeFilter(
     res = double(length(fns))
     for (i in seq_along(fns)) {
       subtask = subsetTask(task, features = fns[i])
-      res[i] = resample(learner = perf.learner, task = subtask, resampling = perf.resampling, measures = perf.measure, show.info = FALSE)$aggr
+      res[i] = resample(learner = perf.learner, task = subtask, resampling = perf.resampling, measures = perf.measure, keep.pred = FALSE, show.info = FALSE)$aggr
     }
     if (perf.measure[[1L]]$minimize)
       res = -1.0 * res
