@@ -40,8 +40,9 @@ makeMulticlassWrapper = function(learner, mcw.method = "onevsrest") {
   pv = list(mcw.method = mcw.method)
   id = paste(learner$id, "multiclass", sep = ".")
 
-  x = makeHomogeneousEnsemble(id = id, next.learner = learner, package = learner$package,  par.set = ps,
-    par.vals = pv, learner.subclass = "MulticlassWrapper", model.subclass = "MulticlassModel")
+  x = makeHomogeneousEnsemble(id = id, type = "classif", next.learner = learner,
+    package = learner$package,  par.set = ps, par.vals = pv,
+    learner.subclass = "MulticlassWrapper", model.subclass = "MulticlassModel")
   x = addProperties(x, props = "multiclass")
   x = removeProperties(x, props = "prob")
   x = setPredictType(x, predict.type = "response")
