@@ -25,12 +25,12 @@
 #' @rdname Prediction
 NULL
 
-makePrediction = function(task.desc, row.names, id, truth, predict.type, y, time) {
+makePrediction = function(task.desc, row.names, id, truth, predict.type, predict.threshold = NULL, y, time) {
   UseMethod("makePrediction")
 }
 
 #' @export
-makePrediction.TaskDescRegr = function(task.desc, row.names, id, truth, predict.type, y, time) {
+makePrediction.TaskDescRegr = function(task.desc, row.names, id, truth, predict.type, predict.threshold = NULL, y, time) {
   data = namedList(c("id", "truth", "response", "se"))
   data$id = id
   data$truth = truth
@@ -51,9 +51,12 @@ makePrediction.TaskDescRegr = function(task.desc, row.names, id, truth, predict.
 }
 
 #' @export
-makePrediction.TaskDescClassif = function(task.desc, row.names, id, truth, predict.type, y, time) {
+makePrediction.TaskDescClassif = function(task.desc, row.names, id, truth, predict.type, predict.threshold = NULL, y, time) {
   data = namedList(c("id", "truth", "response", "prob"))
   data$id = id
+  # truth can come from a simple "newdata" df. then there might not be all factor levels present
+  if (!is.null(truth))
+    levels(truth) = union(levels(truth), task.desc$class.levels)
   data$truth = truth
   if (predict.type == "response") {
     data$response = y
@@ -61,7 +64,7 @@ makePrediction.TaskDescClassif = function(task.desc, row.names, id, truth, predi
   } else {
     data$prob = y
     data = as.data.frame(filterNull(data))
-    # fix columnnames for prob if strage chars are in factor levels
+    # fix columnnames for prob if strange chars are in factor levels
     i = grep("prob.", names(data), fixed = TRUE)
     if (length(i))
       names(data)[i] = paste0("prob.", colnames(y))
@@ -76,16 +79,19 @@ makePrediction.TaskDescClassif = function(task.desc, row.names, id, truth, predi
   )
 
   if (predict.type == "prob") {
-    th = rep(1/length(task.desc$class.levels), length(task.desc$class.levels))
-    names(th) = task.desc$class.levels
-    p = setThreshold(p, th)
+    # set default threshold to 1/k
+    if (is.null(predict.threshold)) {
+      predict.threshold = rep(1/length(task.desc$class.levels), length(task.desc$class.levels))
+      names(predict.threshold) = task.desc$class.levels
+    }
+    p = setThreshold(p, predict.threshold)
   }
 
   return(p)
 }
 
 #' @export
-makePrediction.TaskDescSurv = function(task.desc, row.names, id, truth, predict.type, y, time) {
+makePrediction.TaskDescSurv = function(task.desc, row.names, id, truth, predict.type, predict.threshold = NULL, y, time) {
   data = namedList(c("id", "truth.time", "truth.event", "response"))
   data$id = id
   # FIXME: recode times
@@ -103,7 +109,7 @@ makePrediction.TaskDescSurv = function(task.desc, row.names, id, truth, predict.
 }
 
 #' @export
-makePrediction.TaskDescCluster = function(task.desc, row.names, id, truth, predict.type, y, time) {
+makePrediction.TaskDescCluster = function(task.desc, row.names, id, truth, predict.type, predict.threshold = NULL, y, time) {
   data = namedList(c("id", "response", "prob"))
   data$id = id
   if (predict.type == "response") {
@@ -127,7 +133,7 @@ makePrediction.TaskDescCluster = function(task.desc, row.names, id, truth, predi
 }
 
 #' @export
-makePrediction.TaskDescCostSens = function(task.desc, row.names, id, truth, predict.type, y, time) {
+makePrediction.TaskDescCostSens = function(task.desc, row.names, id, truth, predict.type, predict.threshold = NULL, y, time) {
   data = namedList(c("id", "response"))
   data$id = id
   data$response = y
