@@ -64,9 +64,19 @@ getTaskNFeats = function(task) {
   sum(task$task.desc$n.feat)
 }
 
+#' Get number of observations in task.
+#'
+#' @template arg_task
+#' @return [\code{integer(1)}].
+#' @export
+#' @family task
+getTaskSize = function(task) {
+  getTaskDescription(task)$size
+}
+
 #' @export
 #' @rdname getTaskFormula
-getTaskFormulaAsString = function(x, target = getTaskTargetNames(x)) {
+getTaskFormulaAsString = function(x, target = getTaskTargetNames(x), explicit.features = FALSE) {
   td = getTaskDescription(x)
   type = td$type
   if (type == "surv") {
@@ -77,7 +87,14 @@ getTaskFormulaAsString = function(x, target = getTaskTargetNames(x)) {
   } else if (type == "cluster") {
     stop("There is no formula available for clustering.")
   }
-  paste(target, "~.")
+  if (explicit.features) {
+    if (!inherits(x, "Task"))
+      stopf("'explicit.features' can only be used when 'x' is of type 'Task'!")
+    features = getTaskFeatureNames(x)
+  } else {
+    features = "."
+  }
+  paste(target, "~", paste(features, collapse = " + "))
 }
 
 
@@ -87,8 +104,11 @@ getTaskFormulaAsString = function(x, target = getTaskTargetNames(x)) {
 #'
 #' @template arg_task_or_desc
 #' @param target [\code{character(1)}]\cr
-#'   Left hand side of formula.
+#'   Left hand side of the formula.
 #'   Default is defined by task \code{x}.
+#' @param explicit.features [\code{logical(1)}]\cr
+#'   Should the features (right hand side of the formula) be explicitly listed?
+#'   Default is \code{FALSE}, i.e., they will be represented as \code{"."}.
 #' @param env [\code{environment}]\cr
 #'   Environment of the formula. Set this to \code{parent.frame()}
 #'   for the default behaviour.
@@ -96,8 +116,8 @@ getTaskFormulaAsString = function(x, target = getTaskTargetNames(x)) {
 #' @return [\code{formula} | \code{character(1)}].
 #' @family task
 #' @export
-getTaskFormula = function(x, target = getTaskTargetNames(x), env = NULL) {
-  as.formula(getTaskFormulaAsString(x, target = target), env = env)
+getTaskFormula = function(x, target = getTaskTargetNames(x), explicit.features = FALSE, env = NULL) {
+  as.formula(getTaskFormulaAsString(x, target = target, explicit.features = explicit.features))
 }
 
 #' Get target column of task.
@@ -148,9 +168,10 @@ getTaskTargets = function(task, subset, recode.target = "no") {
 #'   Default is FALSE.
 #' @param recode.target [\code{character(1)}]\cr
 #'   Should target classes be recoded? Only for binary classification.
-#'   Possible are \dQuote{no} (do nothing), \dQuote{01}, and \dQuote{-1+1}.
+#'   Possible are \dQuote{no} (do nothing), \dQuote{01}, \dQuote{-1+1} and \dQuote{drop.levels}.
 #'   In the two latter cases the target vector is converted into a numeric vector.
 #'   The positive class is coded as +1 and the negative class either as 0 or -1.
+#'   \dQuote{drop.levels} will remove empty factor levels in the target column.
 #'   Default is \dQuote{no}.
 #' @return Either a data.frame or a list with data.frame \code{data} and vector \code{target}.
 #' @family task
@@ -205,6 +226,8 @@ getTaskData = function(task, subset, features, target.extra = FALSE, recode.targ
 recodeY = function(y, type, td) {
   if (type == "no")
     return(y)
+  if (type == "drop.levels")
+    return(factor(y))
   if (type == "01")
     return(as.numeric(y == td$positive))
   if (type == "-1+1")
@@ -276,12 +299,11 @@ getTaskCosts = function(task, subset) {
 
 #' Subset data in task.
 #'
-#' @param task [\code{\link{Task}}]\cr
-#'   The task.
+#' @template arg_task
 #' @param subset [\code{integer} | \code{logical(n)}]\cr
 #'   Selected cases.
 #'   Default is all cases.
-#' @param features [character]\cr
+#' @param features [\code{character}]\cr
 #'   Selected inputs. Note that target feature is always included in the
 #'   resulting task, you should not pass it here.
 #'   Default is all features.
