@@ -81,7 +81,7 @@ makeWeightedClassesWrapper = function(learner, wcw.param = NULL, wcw.weight = 1)
   ps = makeParamSet(
     makeNumericVectorLearnerParam(id = "wcw.weight", len = NA_integer_, lower = 0)
   )
-  x = makeBaseWrapper(id, learner, package = learner$package, par.set = ps, par.vals = pv,
+  x = makeBaseWrapper(id, learner$type, learner, package = learner$package, par.set = ps, par.vals = pv,
     learner.subclass = "WeightedClassesWrapper", model.subclass = "WeightedClassesModel")
   x$wcw.param = wcw.param
   removeProperties(x, "weights")
