@@ -1,6 +1,5 @@
 tuneGenSA = function(learner, task, resampling, measures, par.set, control, opt.path, show.info) {
-
-  requirePackages("GenSA", why = "tuneGenSA")
+  requirePackages("GenSA", why = "tuneGenSA", default.method = "load")
 
   low = getLower(par.set)
   upp = getUpper(par.set)
@@ -10,10 +9,9 @@ tuneGenSA = function(learner, task, resampling, measures, par.set, control, opt.
   start = convertStartToNumeric(start, par.set)
   ctrl.gensa = control$extra.args
   cx = function(x) convertXNumeric(x, par.set)
-  or = GenSA::GenSA(par = start, fn = tunerFitnFun, lower = low, upper = upp, control = ctrl.gensa,
+  GenSA::GenSA(par = start, fn = tunerFitnFun, lower = low, upper = upp, control = ctrl.gensa,
     learner = learner, task = task, resampling = resampling, measures = measures,
     par.set = par.set, ctrl = control, opt.path = opt.path, show.info = show.info,
     convertx = cx, remove.nas = FALSE)
   makeTuneResultFromOptPath(learner, par.set, measures, control, opt.path)
 }
-
