@@ -15,11 +15,13 @@ setDefaultImputeVal = function(control, measures) {
 
 # get one or multiple thresholds vector from optpath rows
 # if we have multiple rows we average the result
+# subset to those elements, which begin with "threshold." and also remove that prefix
 getThresholdFromOptPath = function(opt.path, inds) {
   ths = asMatrixCols(lapply(inds, function(i) {
     ex = getOptPathEl(opt.path, i)$extra
     ns = names(ex)
-    ex[grepl("^threshold", ns)]
+    ex = ex[grepl("^threshold", ns)]
+    setNames(ex, sub("^threshold\\.", "", names(ex)))
   }))
   rowMeans(ths)
 }
