@@ -33,6 +33,7 @@ registerS3method("makeRLearner", "classif.mock2", makeRLearner.classif.mock2)
 registerS3method("trainLearner", "classif.mock2", trainLearner.classif.mock2)
 registerS3method("predictLearner", "classif.mock2", predictLearner.classif.mock2)
 
+
 # learner with error "foo" in train
 makeRLearner.classif.mock3 = function() {
   makeRLearnerClassif(
@@ -46,3 +47,27 @@ registerS3method("makeRLearner", "classif.mock3", makeRLearner.classif.mock3)
 registerS3method("trainLearner", "classif.mock3", trainLearner.classif.mock3)
 registerS3method("predictLearner", "classif.mock3", predictLearner.classif.mock3)
 
+# learner with different "when" settings for hyperpars
+makeRLearner.regr.mock4 = function() {
+  makeRLearnerRegr(
+    cl = "regr.mock4", package = character(0L),
+    par.set = makeParamSet(
+      makeNumericLearnerParam("p1", when = "train"),
+      makeNumericLearnerParam("p2", when = "predict"),
+      makeNumericLearnerParam("p3", when = "both")
+    ),
+    properties = c("missings", "numerics", "factors")
+  )
+}
+
+trainLearner.regr.mock4 = function(.learner, .task, .subset, .weights = NULL, p1, p3, ...) {
+  list(foo = p1 + p3)
+}
+
+predictLearner.regr.mock4 = function(.learner, .model, .newdata, p2, p3) {
+  y = rep(1, nrow(.newdata))
+  y * .model$learner.model$foo + p2 + p3
+}
+registerS3method("makeRLearner", "regr.mock4", makeRLearner.regr.mock4)
+registerS3method("trainLearner", "regr.mock4", trainLearner.regr.mock4)
+registerS3method("predictLearner", "regr.mock4", predictLearner.regr.mock4)
