@@ -22,3 +22,9 @@ test_that("basic PreprocWrapperCaret works", {
   ctrl$call = NULL
   expect_equal(mod, ctrl)
 })
+
+test_that("PreprocWrapperCaret supports missing values", {
+  lrn1 = makeLearner("classif.svm")
+  lrn2 = makePreprocWrapperCaret(lrn1, ppc.knnImpute = TRUE)
+  expect_true(hasProperties(lrn2, props = "missings"))
+})
