@@ -5,8 +5,8 @@ test_that("classif_LiblineaRMultiClass", {
 
   set.seed(getOption("mlr.debug.seed"))
   m = LiblineaR::LiblineaR(data=multiclass.train[, -multiclass.class.col],
-                labels=multiclass.train[, multiclass.target],
-                type=4)
+                target = multiclass.train[, multiclass.target],
+                type = 4)
   p = predict(m, newx=multiclass.test[, -multiclass.class.col])
   old.predicts = as.factor(p$predictions)
 
